@@ -65,8 +65,8 @@ def send_notifications(email, sender, email_configuration):
     SUBJECT = email_configuration.get('Subject')
 
     # The full path to the file that will be attached to the email.
-    LOG_PATH = email_configuration.get('Log_path')
-    ATTACHMENT = LOG_PATH
+    # LOG_PATH = email_configuration.get('Log_path')
+    ATTACHMENT = getattr(settings, "LOG_PATH", None)
 
     # # The HTML body of the email.
     file_name = email_configuration.get('HTML_File')
